
function EIDOLON_scale=Apply_Disarray(RANDF_scale,Diff_scaleim)

%  USAGE:   EIDOLON_scale=Apply_Disarray(RANDF_scale,Diff_scaleim)
% 
% Applies disarray to scale decomposed image. When disarray forces pixels outside of the image boundary to be attributed to eidolon, the algorithm WRAPS AROUND.
% 
% INPUTS:
% 
% RANDF_scale: cell array containing random displacement fields for each scale (each cell one scale, finest to coarsest. Each field NxMx2, two layers being for x and y)
% Diff_scaleim: Cell array containing the image components (1 cell per scale, cell contents are MxN or MxNx3 matrices for grayscale or color images);
% 
% OUTPUTS:
% 
% EIDOLON_scale: Cell array containing the eidolon components (1 cell per scale, cell contents are MxN or MxNx3 matrices for grayscale or color images);
% 

imsiz=size(RANDF_scale{1});

NLAYERS=length(size(Diff_scaleim{1}));
% Grayscale image only has x and y coordinates 
if NLAYERS==2
    NLAYERS=1;
end


[OrpIxInd{2} OrpIxInd{1}]=meshgrid(1:imsiz(2),1:imsiz(1));

for nscale=1:length(RANDF_scale);
    for ncoordinate=1:2
        NewPixind{ncoordinate}=round(OrpIxInd{ncoordinate}+RANDF_scale{nscale}(:,:,ncoordinate));
        % fix pixels reaching outside of image WRAPPING AROUND
        NewPixind{ncoordinate}(NewPixind{ncoordinate}<1)=imsiz(ncoordinate)-NewPixind{ncoordinate}(NewPixind{ncoordinate}<1);
        NewPixind{ncoordinate}(NewPixind{ncoordinate}>imsiz(ncoordinate))=NewPixind{ncoordinate}(NewPixind{ncoordinate}>imsiz(ncoordinate))-imsiz(ncoordinate);
    end
   
    for LAY=1:NLAYERS
        v_Diff_scaleim=Diff_scaleim{nscale}(:,:,LAY);
        sizlay=size(v_Diff_scaleim);
        v_Diff_scaleim=v_Diff_scaleim(:);
        linearInd = sub2ind(sizlay, NewPixind{1}(:), NewPixind{2}(:));
        EIDOLON_scale{nscale}(:,:,LAY)=reshape(v_Diff_scaleim(linearInd),sizlay);
    end
end
