
function EIDOLON=Apply_Disarray_noscale(image_matrix,RANDF)

%  USAGE:   EIDOLON=Apply_Disarray_noscale(image_matrix,RANDF)
%
% Applies disarray to image. When disarray forces pixels outside of the
% image boundary to be attributed to eidolon, the algorithm WRAPS AROUND.
% Since no scales are defined, no further assembly is needed.
%
% INPUTS:
%
% image_matrix: NxM or NxMx3 image matrix.
%
% RANDF: c random displacement field(NxMx2, two layers being for x and y)
% 
% OUTPUTS:
%
% EIDOLON: new eidolon instance, same format as image_matrix
%

imsiz=size(image_matrix);

NLAYERS=length(size(image_matrix));
% Grayscale image only has x and y coordinates
if NLAYERS==2
    NLAYERS=1;
end


[OrpIxInd{2} OrpIxInd{1}]=meshgrid(1:imsiz(2),1:imsiz(1));


for ncoordinate=1:2
    NewPixind{ncoordinate}=round(OrpIxInd{ncoordinate}+RANDF(:,:,ncoordinate));
    % fix pixels reaching outside of image WRAPPING AROUND
    NewPixind{ncoordinate}(NewPixind{ncoordinate}<1)=imsiz(ncoordinate)-NewPixind{ncoordinate}(NewPixind{ncoordinate}<1);
    NewPixind{ncoordinate}(NewPixind{ncoordinate}>imsiz(ncoordinate))=NewPixind{ncoordinate}(NewPixind{ncoordinate}>imsiz(ncoordinate))-imsiz(ncoordinate);
end

for LAY=1:NLAYERS
    onelay=image_matrix(:,:,LAY);
    sizlay=size(onelay);
    v_onelay=onelay(:);
    linearInd = sub2ind(sizlay, NewPixind{1}(:), NewPixind{2}(:));
    EIDOLON(:,:,LAY)=reshape(v_onelay(linearInd),sizlay);
end

