function EDGE_KRNL_SPECT=Setup_Edge_Kernels(IMSIZE,PixScaleSizes);

%USAGE:   EDGE_KRNL_SPECT=Setup_Edge_Kernels(IMSIZE,PixScaleSizes);
%
%Sets up spectra of (shifted) Edge finding kernels at different scales to be used to lowpass the
%image
%
% INPUTS:
%
% IMSIZE: vector defining size of input image (NxM for grayscale or NxMx3 for color image)
% PixScaleSizes: vector defining STD values of Edge finder kernel for each scale
%
% OUTPUTS:
%
% EDGE_KRNL_SPECT: cell array containing spectra of the edge finding kernels at each scale and for each of the three angles


for nscl=1:length(PixScaleSizes)    
    
    [X,Y]=meshgrid((1:IMSIZE(2))-mean(1:IMSIZE(2)),(1:IMSIZE(1))-mean(1:IMSIZE(1)));
    k=1/(sqrt(2*pi*PixScaleSizes(nscl)^2));
    f=k*exp(-0.5*((X.^2/((PixScaleSizes(nscl)^2)))+(Y.^2/((PixScaleSizes(nscl)^2)))));
    gauss_x=(-X./(PixScaleSizes(nscl)^2)).*f;
    krnl=gauss_x.*(-X./(PixScaleSizes(nscl)^2))+(-f/(PixScaleSizes(nscl)^2));
    krnl=krnl-mean(krnl(:));
    krnl=krnl/sum(abs(krnl(:)));
    EDGE_KRNL_SPECT{nscl,1}=fft2(fftshift(krnl));
    
    [THETA,RHO] = cart2pol(X,Y);
    theta=THETA+pi/3;
    [x,y] = pol2cart(THETA,RHO);
    f=k*exp(-0.5*((x.^2/((PixScaleSizes(nscl)^2)))+(Y.^2/((PixScaleSizes(nscl)^2)))));
    gauss_x=(-x./(PixScaleSizes(nscl)^2)).*f;
    krnl=gauss_x.*(-x./(PixScaleSizes(nscl)^2))+(-f/(PixScaleSizes(nscl)^2));
    krnl=krnl-mean(krnl(:));
    krnl=krnl/sum(abs(krnl(:)));
    EDGE_KRNL_SPECT{nscl,2}=fft2(fftshift(krnl));
    
    theta=THETA+2*pi/3;
    [x,y] = pol2cart(theta,RHO);
    f=k*exp(-0.5*((x.^2/((PixScaleSizes(nscl)^2)))+(Y.^2/((PixScaleSizes(nscl)^2)))));
    gauss_x=(-x./(PixScaleSizes(nscl)^2)).*f;
    krnl=gauss_x.*(-x./(PixScaleSizes(nscl)^2))+(-f/(PixScaleSizes(nscl)^2));
    krnl=krnl-mean(krnl(:));
    krnl=krnl/sum(abs(krnl(:)));
    EDGE_KRNL_SPECT{nscl,3}=fft2(fftshift(krnl));
    
end
