function GAUSS_KRNL_SPECT=Setup_Gaussian_Kernels(IMSIZE,PixScaleSizes);

%USAGE:   GAUSS_KRNL_SPECT=Setup_Gaussian_Kernels(IMSIZE,PixScaleSizes);
% 
%Sets up spectra of (shifted) Gausssian kernels at different scales to be used to lowpass the
%image
% 
% INPUTS: 
% 
% IMSIZE: vector defining size of input image (NxM for grayscale or NxMx3 for color image)
% PixScaleSizes: vector defining STD values of Gaussian kernel for each scale
% 
% OUTPUTS:
% 
% GAUSS_KRNL_SPECT: cell array containing spectra of the Gaussian kernels at each scale 


for nscl=1:length(PixScaleSizes)
    krnl=fspecial('gaussian',IMSIZE(1:2), PixScaleSizes(nscl));
    krnl=krnl/sum(krnl(:));
    
    
GAUSS_KRNL_SPECT{nscl}=fft2(fftshift(krnl));
end
