function RANDF=Setup_disarray_noscale(GAUSS_KRNL_SPECT,REACH)
% 
% USAGE:   RANDF=Setup_disarray_noscale(GAUSS_KRNL_SPECT,REACH)
% 
% Sets up random displacement fields (for x and y coordinates), no scales defined. 
% Starting points are gaussian random fields (NxMx2, two layers being for x
% and y) which are low-passed with the appropriate Gaussian kernel
% 
% INPUTS: 
% 
% GAUSS_KRNL_SPECT: the spectrum of the Gaussian kernel
% REACH: scalar containing reach (maximum displacement in pixels) to be applied 
% 
% OUTPUTS:
% 
% RANDF: random displacement fields (NxMx2, two layers being for x and y)
% 

if length(GAUSS_KRNL_SPECT)>1
    error('GAUSS_KRNL must have only 1 cell (no scales defined')
end

imsiz=size(GAUSS_KRNL_SPECT{1});

% random field
RANDF_x=fft2(randn(imsiz(1),imsiz(2)));
RANDF_y=fft2(randn(imsiz(1),imsiz(2)));
    
% filter random field
    RANDF(:,:,1)=real(ifft2(RANDF_x.*GAUSS_KRNL_SPECT{1}));
    RANDF(:,:,2)=real(ifft2(RANDF_y.*GAUSS_KRNL_SPECT{1}));    
    RANDF=RANDF./std(RANDF(:));
    % normalize to std=1

    % Multiply by reach value 
    RANDF=RANDF*REACH;   
end