
clear all; close all; clc;

% % Set up grayscale demo image
% image_matrix=zeros(300,400);
% image_matrix(100:200,50:250)=127;
% image_matrix(150:250,200:350)=image_matrix(150:250,200:350)+127;

% Set up color demo image
image_matrix=zeros(300,400,3);
image_matrix(100:200,50:250,2)=127;
image_matrix(130:250,180:350,1)=image_matrix(130:250,180:350,1)+127;


% Show Original Image
figure; 
hold on;
imshow(uint8(image_matrix));
title('Input Image');

%%% Fully Coherent Disarray with fixed reach

REACH=[10]; % Reach is 10 pixels for all scales
COHERENCE=1; % Coherence from 0 to 1
eidolon=make_eidolon(image_matrix,REACH, COHERENCE);
figure;
imshow(uint8(eidolon));
title('Eidolon, fully coherent disarray');

%%% Partially coherent disarray with reach increasing from finest to
%%% coarsest scale

REACH=[2:10]; % Reach goes from 2 to 10 pixels from finest to coarsest scale
COHERENCE=.5; % Coherence from 0 to 1
eidolon=make_eidolon(image_matrix,REACH, COHERENCE);
figure;
imshow(uint8(eidolon));
title('Eidolon, partially coherent disarray');

%%% Fully incoherent disarray, reach is fixed for all scales

REACH=[10]; % Reach is 10 pixels for all scales
COHERENCE=0; % Coherence from 0 to 1
eidolon=make_eidolon(image_matrix,REACH, COHERENCE);
figure;
imshow(uint8(eidolon));
title('Eidolon, incoherent disarray');

%%% Fully coherent disarray applied only to the three finest scales

REACH=[5 5 5]; % disarraying only the finer scales (WARNING ONLY THREE SCALES IMPLEMENTED)
COHERENCE=1; % Coherence from 0 to 1
eidolon=make_eidolon(image_matrix,REACH, COHERENCE);
figure;
imshow(uint8(eidolon));
title('Eidolon, only finer scales disarrayed');

%%% Fully coherent disarray applied to the scales 7-9 (rather coarse)

REACH=[0 0 0 0 0 0 10 10 10]; % disarraying only coarse scales (WARNING ONLY NINE SCALES IMPLEMENTED)
COHERENCE=1; % Coherence from 0 to 1
eidolon=make_eidolon(image_matrix,REACH, COHERENCE);
figure;
imshow(uint8(eidolon));
title('Eidolon, only coarser scales disarrayed');

%%% Fully coherent disarray. Three scales are defined with user-defined smoothing kernels and each with user-defined reach. 
REACH=[1 3 6];  
COHERENCE=1; % Coherence from 0 to 1
FIX_STD=[1 3 6]; % Standard deviations of smoothing kernels.
eidolon=make_eidolon(image_matrix,REACH, COHERENCE,FIX_STD); % Disarray scales defined by user by a user-defined reach (WARNING ONLY THREE SCALES IMPLEMENTED)
figure;
imshow(uint8(eidolon));
title('Eidolon, user-defined scales');

%%% Fully coherent disarray. Reach fixed across scales, mask confines
%%% disarray to the upper-left quadrant of the image

DISARRAY_MASK=zeros(size(image_matrix,1),size(image_matrix,2));
DISARRAY_MASK(1:round(size(image_matrix,1)/2),1:round(size(image_matrix,2)/2))=1;
eidolon=make_eidolon(image_matrix,5, 1,[],DISARRAY_MASK); % Disarray limited to a masked area.
figure;
imshow(uint8(eidolon));
title('Eidolon, masked disarray.');

%%%  Disarray image (no scale decomposition), limited to the masked area
%%%  from previous example.

REACH=10; % reach in pixel
NOISE_FILTER_STD=10; % Standard Deviation of kernel used to filter random noise field ('grain').

eidolon=disarray_image(image_matrix,REACH,NOISE_FILTER_STD,DISARRAY_MASK);
figure;
imshow(uint8(eidolon));
title('IMAGE DISARRAY (no scale decomposition), masked disarray.');



